"""Constants that are common across the dashboard."""

CUSTOM_DATA = "custom_data"
HOVER_TEXT_HEADERS = "hover_text_headers"
DATE_VALID = "Date valid"
CHART_LABEL_FONT_SIZE = 19
FINANCIAL_YEAR_ENDING = "Financial year ending"
VALUE = "Value"
MAIN_TITLE = "main_title"
SUBTITLE = "subtitle"
MEASURE = "measure"
FILL_TO_PREVIOUS_TRACE = "Fill to previous trace"
REMOVE_INITIAL_MARKER = "Remove initial marker"
YEAR = "Year"


UNIT_SIZE = "Unit size"
DEFAULT_COLOURSCALE = "tealgrn"

LEGEND_SPACING = "\u00a0" * 5

DOWNLOAD_BUTTON_CLASSES = (
    "govuk-button govuk-button--primary "
    "govuk-!-margin-bottom-0 govuk-!-margin-top-4 "
    "flex w-auto items-center gap-2 print:hidden"
)
